package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````D!X```````!``````````&BU````
M`````````$``.``(`$``'0`<``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````7`````````!<``````````0`````````!````
M!0```````````````````````````````````*R?````````K)\`````````
M`"````````$````&````N*T```````"XK2```````+BM(```````L`0`````
M```0!0``````````(````````@````8```#@K0```````."M(```````X*T@
M``````#``0```````,`!````````"``````````$````!````!@"````````
M&`(````````8`@```````"P`````````+``````````$`````````%#E=&0$
M````_)@```````#\F````````/R8````````'`$````````<`0````````0`
M````````4N5T9`0```"XK0```````+BM(```````N*T@``````!(`@``````
M`$@"`````````0`````````O=7-R+VQI8F5X96,O;&0N96QF7W-O```'````
M!`````$```!.971"4T0```#*FCL$````!`````,```!085@```````````!A
M````9```````````````,0```!L```````````````<```!.`````@``````
M``!"`````````#X````0````2``````````S````!0```!8```!'````4@``
M``L```!+````"0```!P`````````%0```%P```!`````30`````````P````
M8@```&,````:````10```$P```!$````6P```!X`````````"@```#P```!#
M````,@```"$```!9`````````#L````T`````````"T````X````6@```"0`
M```H````8````%$```!>`````````%<`````````5@```"H````.````````
M````````````4````"L`````````)@```%\````V`````````#T`````````
M-P```&$`````````4P```!D````4`````````%0`````````````````````
M````00````````!8````+P```#4`````````70``````````````````````
M``````````````$`````````````````````````````````````````````
M```````````````````````$``````````P`````````````````````````
M````````````````````````````````$0``````````````````````````
M````$P`````````C```````````````#````````````````````*0``````
M```/`````````"4`````````+``````````````````````````(````&```
M````````````````````````````)P``````````````%P```"(`````````
M`````#\````=````$@`````````````````````````````````````````&
M`````````$8```!/````2@```````````````````"```````````````#D`
M``!)````.@```%4`````````#0```!\````N````````````````````````
M`````````````````&<#```2``P`>E8```````#\`0```````,<!```2````
M`````````````````````,0````1`````````````````````````+D!```2
M`````````````````````````&X````2``````````````````````````P`
M```2`````````````````````````'H!```2````````````````````````
M`&P#```2``P`O3$````````:`````````&X"```2````````````````````
M`````"L"```2`````````````````````````(\````0``T`@%@`````````
M`````````!H"```2`````````````````````````(8!```2````````````
M`````````````,\!```@`````````````````````````(8"```2````````
M`````````````````#("```2`````````````````````````+L"```2````
M``````````````````````L#```1`!<`^+$@```````(`````````/$"```2
M`````````````````````````.<!```2`````````````````````````'0`
M```2`````````````````````````(<#```2``P``"D````````#````````
M`)4````2`````````````````````````"\!```2````````````````````
M`````!0````2`````````````````````````%H"```@````````````````
M`````````#\````2`````````````````````````!8#```1`!@`@+(@````
M```(`````````$<````2``````````````````````````\"```2````````
M`````````````````)@#```2``P`US$```````#G`````````/T````2````
M`````````````````````*H#```2``P`OC(```````""!@```````"0$```0
M``D`D!H``````````````````-H"```2`````````````````````````(P"
M```2`````````````````````````",#```2````````````````````````
M`#$````2`````````````````````````$`"```2````````````````````
M`````+<#```2``P`@2@````````R`````````-\````6````````````````
M`````````/(````2`````````````````````````$@!```2````````````
M`````````````+\#```2``P`D!X``````````````````#@````2````````
M`````````````````-$````2`````````````````````````,<#```2``P`
M@2\```````!6`````````-4#```2``P`0#D````````\`@```````.L#```2
M``P`\E$```````#G`0```````/8#```1`!<`8+(@```````(`````````*4`
M```2`````````````````````````,`#```2``P`D!X`````````````````
M`+8"```1``````````````````````````8!```1`!@`P+(@```````(````
M```````$```2``P`Y2H````````O``````````X!```2````````````````
M`````````#8!```1`````````````````````````&L!```2````````````
M`````````````!P````B`````````````````````````/D!```@````````
M`````````````````#`#```2`````````````````````````#\#```2````
M`````````````````````$$"```2`````````````````````````'T"```2
M``````````````````````````T$```0`!@`:+(@`````````````````",!
M```2`````````````````````````&8!```2````````````````````````
M`%\````2`````````````````````````!D$```2``P`UR\```````"\````
M`````"L````2`````````````````````````$\````2````````````````
M`````````"$$```2``P`H5$```````!1`````````$D"```2````````````
M`````````````"H$```2``P`%"L```````!@`````````/,!```2````````
M`````````````````#8$```2``P`="L````````-!````````*<"```2````
M`````````````````````#T#```2`````````````````````````%@!```2
M`````````````````````````(H````2`````````````````````````#D"
M```2`````````````````````````$,$```0`!<`:+(@````````````````
M`$H$```2``P``RD```````#B`0```````*8!```2````````````````````
M`````%<$```2``P`V5,```````"1`@```````'L````2````````````````
M`````````$0#```2`````````````````````````)L!```2````````````
M`````````````$\#```2`````````````````````````%8#```2````````
M`````````````````)$"```2`````````````````````````&(#```0`!@`
MR+(@`````````````````)X````2`````````````````````````(4````2
M`````````````````````````*`"```2`````````````````````````+,`
M```2`````````````````````````&$$```2``P`?#L```````!E````````
M`)D"```2`````````````````````````!<!```2````````````````````
M``````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA;&EZ
M90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T870U
M,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``;65M8W!Y`'!E<FQ?9&5S=')U
M8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S971P
M=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E;G9I
M<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E<FQ?<V%F97-Y<VUA;&QO8P!?
M7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S<')I;G1F7V-H
M:P!R96%D`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?;F5W6%,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<WES7W1E<FT`7U]E<G)N;P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!097)L
M7VUG7W-E=`!M:V1I<@!?7W)E9VES=&5R7V9R86UE7VEN9F\`<&5R;%]P87)S
M90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`;65M8VAR`'9F<')I
M;G1F`%!E<FQ?871F;W)K7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L
M7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P<FEN=&8`9V5T=6ED
M`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M<`!L:6)M+G-O+C``
M;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS;RXQ`'!T:')E861?
M871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN9W,`7U]G
M971P=W5I9#4P`%]?<W1P8W!Y7V-H:P!A=&5X:70`7VQI8F-?:6YI=`!S=')T
M;VL`7U]R96%D9&ER,S``7V5N9`!M86EN`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`7U]S=&%R=`!P87)?96YV7V-L96%N`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S
M96YA;64`7U]B<W-?<W1A<G0`<&%R7V1I90!S:&%?:6YI=`!P87)?9&ER;F%M
M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`
M<&%R7V-L96%N=7``+W5S<B]P:V<O;&EB+W!E<FPU+S4N,S@N,"]X.#9?-C0M
M;F5T8G-D+71H<F5A9"UM=6QT:2]#3U)%.B]U<W(O<&MG+VQI8@``````L*\@
M```````(`````````."M(```````^+$@```````(`````````(BR(```````
M`+(@```````(``````````"R(```````8+(@```````(`````````'A;````
M````H*\@```````&`````P``````````````J*\@```````&````#@``````
M````````N*\@```````&````&@``````````````P*\@```````2````*0``
M````````````R*\@```````&````-0``````````````T*\@```````&````
M.0``````````````V*\@```````&````.P``````````````X*\@```````&
M````/```````````````Z*\@```````&````1P``````````````\*\@````
M```&````20``````````````^*\@```````&````5```````````````&+`@
M```````'`````@``````````````(+`@```````'````!```````````````
M*+`@```````'````!0``````````````,+`@```````'````!@``````````
M````.+`@```````'````!P``````````````0+`@```````'````"0``````
M````````2+`@```````'````"@``````````````4+`@```````'````#```
M````````````6+`@```````'````#0``````````````8+`@```````'````
M#P``````````````:+`@```````'````$```````````````<+`@```````'
M````$0``````````````>+`@```````'````$P``````````````@+`@````
M```'````%```````````````B+`@```````'````%0``````````````D+`@
M```````'````%P``````````````F+`@```````'````&```````````````
MH+`@```````'````&0``````````````J+`@```````'````&P``````````
M````L+`@```````'````'0``````````````N+`@```````'````'@``````
M````````P+`@```````'````(```````````````R+`@```````'````(P``
M````````````T+`@```````'````)```````````````V+`@```````'````
M)0``````````````X+`@```````'````)@``````````````Z+`@```````'
M````)P``````````````\+`@```````'````*@``````````````^+`@````
M```'````*P```````````````+$@```````'````+0``````````````"+$@
M```````'````+@``````````````$+$@```````'````,P``````````````
M&+$@```````'````.```````````````(+$@```````'````.@``````````
M````*+$@```````'````/0``````````````,+$@```````'````/@``````
M````````.+$@```````'````/P``````````````0+$@```````'````0```
M````````````2+$@```````'````0@``````````````4+$@```````'````
M0P``````````````6+$@```````'````1```````````````8+$@```````'
M````1@``````````````:+$@```````'````2P``````````````<+$@````
M```'````30``````````````>+$@```````'````3@``````````````@+$@
M```````'````3P``````````````B+$@```````'````4```````````````
MD+$@```````'````40``````````````F+$@```````'````5@``````````
M````H+$@```````'````5P``````````````J+$@```````'````6```````
M````````L+$@```````'````60``````````````N+$@```````'````6@``
M````````````P+$@```````'````6P``````````````R+$@```````'````
M70``````````````T+$@```````'````7@``````````````V+$@```````'
M````7P``````````````X+$@```````'````8```````````````Z+$@````
M```'````8@``````````````\+$@```````'````8P``````````````````
M``````!(@^P(Z%('``!(@\0(PP``_S5BE2``_R5DE2``#Q]``/\E8I4@`&@`
M````Z>#_____)5J5(`!H`0```.G0_____R52E2``:`(```#IP/____\E2I4@
M`&@#````Z;#_____)4*5(`!H!````.F@_____R4ZE2``:`4```#ID/____\E
M,I4@`&@&````Z8#_____)2J5(`!H!P```.EP_____R4BE2``:`@```#I8/__
M__\E&I4@`&@)````Z5#_____)1*5(`!H"@```.E`_____R4*E2``:`L```#I
M,/____\E`I4@`&@,````Z2#_____)?J4(`!H#0```.D0_____R7RE"``:`X`
M``#I`/____\EZI0@`&@/````Z?#^____)>*4(`!H$````.G@_O___R7:E"``
M:!$```#IT/[___\ETI0@`&@2````Z<#^____)<J4(`!H$P```.FP_O___R7"
ME"``:!0```#IH/[___\ENI0@`&@5````Z9#^____);*4(`!H%@```.F`_O__
M_R6JE"``:!<```#I</[___\EHI0@`&@8````Z6#^____)9J4(`!H&0```.E0
M_O___R62E"``:!H```#I0/[___\EBI0@`&@;````Z3#^____)8*4(`!H'```
M`.D@_O___R5ZE"``:!T```#I$/[___\E<I0@`&@>````Z0#^____)6J4(`!H
M'P```.GP_?___R5BE"``:"````#IX/W___\E6I0@`&@A````Z=#]____)5*4
M(`!H(@```.G`_?___R5*E"``:",```#IL/W___\E0I0@`&@D````Z:#]____
M)3J4(`!H)0```.F0_?___R4RE"``:"8```#I@/W___\E*I0@`&@G````Z7#]
M____)2*4(`!H*````.E@_?___R4:E"``:"D```#I4/W___\E$I0@`&@J````
MZ4#]____)0J4(`!H*P```.DP_?___R4"E"``:"P```#I(/W___\E^I,@`&@M
M````Z1#]____)?*3(`!H+@```.D`_?___R7JDR``:"\```#I\/S___\EXI,@
M`&@P````Z>#\____)=J3(`!H,0```.G0_/___R72DR``:#(```#IP/S___\E
MRI,@`&@S````Z;#\____)<*3(`!H-````.F@_/___R6ZDR``:#4```#ID/S_
M__\ELI,@`&@V````Z8#\____):J3(`!H-P```.EP_/___R6BDR``:#@```#I
M8/S___\EFI,@`&@Y````Z5#\____)9*3(`!H.@```.E`_/___R6*DR``:#L`
M``#I,/S___\E,I$@`&:0_R4ZD2``9I#_)5*1(`!FD/\E4I$@`&:02(/D\$B#
M[`A(B==(B=[IS@$``&8N#Q^$```````/'P!52(GE05132(T=^HX@`$R-)?..
M(`!,.>-S"_\32(/#"$PYXW+U6T%<7<-52(GE055!5%-(@^P(2,?#`````$G'
MQ0````!,.>MS'8-[""4/A6PW``!,BR/_4Q!)B00D2(/#&$PYZW+C2(/$"%M!
M7$%=7<-(8])(8_9(C40R`DB-%,>+`H7`#X0R`0``OO____\QR>L3@_@##X07
M`0``2(/"$(L"A<!T((/X!70-@_@'=>-(@WH(`'3EPP^W<@A(@\(0BP*%P'7@
M2(7)#X3M````9H/^_P^$XP````^WQDAKP#A(`<A(.<@/AM````"^_____S'_
MZQ6#^@9U!TB)SD@K<1!(@\$X2#G(=A.+$8/Z`G7D2(G/2(/!.$@YR'?M2(7_
M#X26````N/____](.<8/A(@```!(BT\02`'Q2(L12(72='DQ_S'`ZQ9(@_H(
M=01(BWD(2(/!$$B+$4B%TG092(/Z!W7D2(M!"$@!\$B#P1!(BQ%(A=)UYT@!
MQT@YQW<5ZSI(BU`02`'R2(D12(/`&$@YQW8G2(L(2`'QBU`(2(/Z"'3>2(/Z
M)73B54B)Y>D1-@``2(M*".G@_O__#Q\`PU5(B>5!5D%5051328G^28GTBU88
MBW8(28L\).B1_O__2(T%Z)$@`$R)($R-+1Z2(`!)BT0D$$F)10!)BP0D2(L0
M2(72#X2Y````2(T--I$@`$B)$4B+``^V$(32=!-(@\`!@/HO=?!(B0$/MA"$
MTG7M387V=`A,B??H@?S__^C,_/__2(,]M(X@```/A(@```!,C36OC"``2(T=
MJ(P@`$PY\W,+_Q-(@\,(3#GS<O5(C3V)_?__Z$3\__],C36%C"``2(T=?HP@
M`$PY\W,+_Q-(@\,(3#GS<O5(C3TO-P``Z!K\___H-?G__T&+?"0(28M5`$F+
M-"3H#34``(G'Z&S[__](C05]D"``2(T-!I$@`$B)".E8____Z$O]___I;O__
M_X`]KI`@``!T`<-3Q@6CD"```4B#/2J.(```=`Q(BSU)D"``Z,3\__](C1T-
MC"``2(L#2(7`=`C_T$B#PPCK\$B#/<V-(```=`Q(C3V$>0``Z(?\__];PX`]
M5I`@``!T`<-3Q@5+D"```4B#/=N-(```=!-(C37ZCR``2(T]4WD``.AN_/__
M2(,]EHT@``!T$DB-/:V+(`!(@S\`=`7H0OS__TB-'7N+(`!(BP-(@_C_=`C_
MT$B#ZPCK[UO#54B)Y4%7059!54%44TB#[!A(B77(2(7_#X2'````2(T%2Y`@
M`$R+,$V%]G1X28G_#[8'2(GZA,!T<#P]=`M(@\(!#[8"A,!U\40I^DV+)DV%
MY'0K3&/J3(GS3(GJ3(G^3(GGZ!CY__^%P'4'0X`\+#UT'DB#PPA,BR--A>1U
MVTR)X$B#Q!A;05Q!74%>05]=PTPI\TC!^P-(BT7(B1A/C60L`>O:13'DZ]4Q
MTNN>54B)Y4%7059!54%44TB![+@```!(BQVWC"``2(L#2(E%R#'`2(7_=`A)
MB?R`/P!U'TB+1<A(*P,/A18!``!(@<2X````6T%<05U!7D%?7</H#?O__TF)
MQDB%P'342(V%,/___TB)A2C___],B??H?_K__TB%P`^$G````$R->`V`>`TN
M=0=!@'\!`'3>@'@-+@^$E@```$R)Y^B3^O__28G%3(G_Z(CZ__]!C7P%`DAC
M_^C[]___28G%3(GY3(GB2(TURS0``$B)QS'`Z#'Z__](B[4H____3(GOZ,+W
M__],B>^#^/]T$HN%./___R4`\```/0!```!T3NB3]___3(GOZ(OY__],B??H
MX_G__TB%P`^%9/___TR)]^CB]___3(GGZ!KY___I!/___T&`?P$N#X5?____
M08!_`@`/A"C____I3____^BS_O__#Q]$``#KJ^CI^?__54B)Y4%44TB![*``
M``!)B?Q(BQUABR``2(L#2(E%Z#'`2(VU4/___^@L^?__A<!U,XN56/___X'B
M`/```('Z`$```'0(@?H`H```=1F^`@```$R)Y^A?]O__A<`/E,`/ML#K`C'`
M2(M-Z$@K"W4,2('$H````%M!7%W#Z&GY__]52(GE05132('L$`0``$B)_DB+
M'>&*(`!(BP-(B47H,<!,C:7@^___N@`$``!,B>?HQ/?__TB#Z`%,.>!W#NL1
MQ@``2(/H`4PYX'0%@#@O=.^^+P```$R)Y^BK]O__2(7`="=,.>!W'4R)Y^C)
M]O__2(M-Z$@K"W4Q2('$$`0``%M!7%W#Q@``Z]Y(BT7H2"L#=1=(C3TE,P``
M2('$$`0``%M!7%WIC_;__^BZ^/__54B)Y4%7059!54%44TB![!@$``!)B?Q)
MB?5(BQTIBB``2(L#2(E%R#'`3(VUP/O__[K_`P``3(GV2(T]TC(``.CE]O__
MA<!^38U0_TQC^D*`O#W`^___`'5UA=)T.$R)^KXO````3(GWZ*SW__](A<!T
M(V1(BP0E`````$@#!;>)(`!,B?E,B?),B>9(BSCHYO3__^L>9$B+!"4`````
M2`,%E(D@`$R)ZDR)YDB+..A6]O__2(M%R$@K`W472('$&`0``%M!7$%=05Y!
M7UW#3&/XZXKHX??__U5(B>5!5T%6055!5%-(@^PH28G\28GV2(L%4XD@`$B+
M&$B)7<@QVX`^/74$28/&`4R)]^B9]___28G%2(UUQ$R)YS'`Z*C[__])B<=(
MA<`/A.D```!(B<?H=/?__TDYQ0^&O@```$AC3<1(C1S-`````$R-/>B+(`!!
M#[84)$R)X(32=1#I?P$``$B#P`$/MA"$TG0%@/H]=?!,*>!(F$D#'TJ-?"@"
MZ*7T__](B0-(A<!T34AC5<1)BP=(BS3028U,)`%!#[8$)(@&A,!U$>MH2(/!
M`0^V0?^(0@&$P'192(GR2(UV`3P]=>;&`CTQP$$/M@P&B$P"`4B#P`&$R77O
M2(L%:8@@`$B+7<A(*Q@/A0@!``!(@\0H6T%<05U!7D%?7<,QP$$/MA0&08@4
M!TB#P`&$TG7OZ\A(B?+KK4R-/1R+(`!-BP])@SD`#X2^````3(G(13'`2(/`
M"$2)PD&#P`%(@S@`=>^-0@-(F$C!X`.+%;F*(`"%TD2)1;QU7DR)3;#'!:.*
M(``!````2(G'Z+OS__](B<=(A<`/A%____](8TV\2(T<S0````!(B=I,BTVP
M3(G.Z*3S__](B<=)B0=$BT6\08U``4B82,<$QP````!$B47$Z9O^__](B<9,
MB<_HF/+__TB)QTF)!TB%P`^$"?___TAC3;Q)B<A(C1S-`````.N^,<#IC_[_
M_[@0````13'`Z57____HO_7__U5(B>5D2(L$)0````!(`P4KAR``2(T-5'``
M`$B+%46'(`!(C34`,```2(LX7>D=]?__54B)Y5-(@^P(9$B+!"4`````2`,%
M](8@`$B)PTB+..BJ____13')3(T%8S$``$R)P4B-%540``!(C374+P``2(L[
M2(/$"%M=Z2#R__\QP,-52(GE05=!5D%505132('LV`0``$F)_$F)]DR++:R&
M(`!)BT4`2(E%R#'`2(VU'/O__TB-/9\O``#H#_G__TB)P[XO````3(GGZ"_S
M__](A<!T-$R)YDB-/80O```QP.CX_/__3(G@2(M5R$DK50`/A68!``!(@<38
M!```6T%<05U!7D%?7<-,B??H?O+__TB)QTB--54O``#H/_3__TF)QTB%P'2M
M08`_``^$V@```$B%VW033(G^2(G?Z)WQ__^%P`^$G@```$R)_^A=]/__28G&
M28U$!_]).<=R#NL<Q@``2(/H`4DYQW0%@#@O=.],B?_H-?3__TF)QDR)Y^@J
M]/__28U$!@%(/?\#```/AS____],C;7`^___3(DD)$R-#:TO``!-B?A(C0W&
M+P``N@`$```Q]DR)]S'`Z#SS__](C;4@^___3(GWZ$WQ__^%P'42BX4H^___
M)0#P```]`(```'1(2(TU@2X``#'_Z&GS__])B<=(A<`/A-/^__]!@#\`#X4F
M____2(7;=`6`.RYT$D&^`0```$R-/?(M``#I5?___X![`0!TNNOFO@$```!,
MB??H4O#__X7`=:=,B?9(C3T8+@``Z([[__],B??H-_'__^F,_O__9I#H6_/_
M_U5(B>5!5$B#[`A)B?R^+P```.CD\/__2(7`=`1,C6`!3(GG2(/$"$%<7>G\
M\/__2(7_=$]52(GE051(@^P(28G\@#\`="#H`//__TB#P`%(/0`$``!W(DR)
MYTB#Q`A!7%WIC/G__TB-/40M``!(@\0(05Q=Z;+P__\QP$B#Q`A!7%W#2(T]
M)RT``.F<\/__54B)Y4%505132(/L&$B+'4B$(`!(BP-(B478,<!,C6743(TM
M5RT``$R)YDR)[S'`Z*?V__](A<!T,$AC5=1(C04'AR``2(L`2(T$T$B+4`A(
MB1!(A=)TT$B#P`A(BU`(2(D02(72=?#KODR-+1<M``!,B>9,B>\QP.A>]O__
M2(7`=#!(8U742(T%OH8@`$B+`$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)
M$$B%TG7PZ[Y,C2W6+```3(GF3(GO,<#H%?;__TB%P'0P2&-5U$B-!76&(`!(
MBP!(C0302(M0"$B)$$B%TG302(/`"$B+4`A(B1!(A=)U\.N^3(TMEBP``$R)
MYDR)[S'`Z,SU__](A<!T,$AC5=1(C04LAB``2(L`2(T$T$B+4`A(B1!(A=)T
MT$B#P`A(BU`(2(D02(72=?#KODR-+50L``!,B>9,B>\QP.B#]?__2(7`=#!(
M8U742(T%XX4@`$B+`$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)$$B%TG7P
MZ[Y,C2T;+```3(GF3(GO,<#H.O7__TB%P'0P2&-5U$B-!9J%(`!(BP!(C030
M2(M0"$B)$$B%TG302(/`"$B+4`A(B1!(A=)U\.N^3(TMB2L``$R)YDR)[S'`
MZ/'T__](A<!T,$AC5=1(C051A2``2(L`2(T$T$B+4`A(B1!(A=)TT$B#P`A(
MBU`(2(D02(72=?#KODR-+94K``!,B>9,B>\QP.BH]/__2(7`=#!(8U742(T%
M"(4@`$B+`$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)$$B%TG7PZ[Y,C2U6
M*P``3(GF3(GO,<#H7_3__TB%P'0P2&-5U$B-!;^$(`!(BP!(C0302(M0"$B)
M$$B%TG302(/`"$B+4`A(B1!(A=)U\.N^3(TM%RL``$R)YDR)[S'`Z!;T__](
MA<!T,$AC5=1(C05VA"``2(L`2(T$T$B+4`A(B1!(A=)TT$B#P`A(BU`(2(D0
M2(72=?#KODR-+6XJ``!,B>9,B>\QP.C-\___2(7`=#!(8U742(T%+80@`$B+
M`$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)$$B%TG7PZ[Y,B>9(C3V,*@``
MZ(GS__](B<9(A<!T#DB-/60J```QP.B"]___3(GF2(T]>"H``#'`Z&+S__](
MB<9(A<!T#DB-/70J```QP.A;]___3(GF2(T];BH``#'`Z#OS__](B<9(A<!T
M-DB-/;<I```QP.@T]___2(M%V$@K`W5(2(TU*BL``$B-/=(I```QP$B#Q!A;
M05Q!75WI#/?__TR)YDB-/2\J```QP.CL\O__2(G&2(7`=+](C3V]*0``,<#H
MY?;__^NOZ+_N__]52(GE4TB#[!A(BQT_@"``2(L#2(E%Z#'`2(UUY$B-/8LI
M``#HIO+__TB%P'0?#[8`A,!T&#PP#Y7`#[;`2(M5Z$@K$W4+2(/$&%M=PS'`
MZ^SH:>[__U5(B>5(@>S0````28GZ2(FU6/___TB)E6#___](B8UH____3(F%
M</___TR)C7C___^$P'0@#RE%@`\I39`/*56@#RE=L`\I9<`/*6W0#REUX`\I
M??!(BP6=?R``2(L(2(F-2/___S')QX4P____"````,>%-/___S````!(C440
M2(F%./___TB-A5#___](B85`____2(V5,/___TR)UDB+!4M_(`!(C;@P`0``
MZ,?K__^__P```.A-[/__54B)Y4%7059!54%44TB![!@``0!!B?U,BR4??R``
M28L$)$B)1<@QP+H"````,?;H>>K__TB#Z`%(NO__``````"`2"'">0](@^H!
M2('*``#__TB#P@%,C;W`__[_3(TUIB@``$@IT$B)PP^(G0```#'22(G>1(GO
MZ##J__](@_C_#X2/````N@@``0!,B?Y$B>_H]NO__TACT(/X_W1,2(/Z!W94
M28U$%_A,.?AR2DB-%0>!(`#K"4B#Z`%,.?AR.$B+"$@Y"G7O3"GX2`'82(MU
MR$DK-"1U3$B!Q!@``0!;05Q!74%>05]=PTB-/24H```QP.A+_O__2('K```!
M`$B!^P``__\/A6/___](Q\#_____Z[E,B?<QP.@D_O__Z6+____H@^S__U5(
MB>7HBNS__XG'Z&/J__](A<!T`TB+`%W#54B)Y4%6055!5%-(@^P028G\3(LM
MX'T@`$F+10!(B478,<!(C7742(T]L2<``.A&\/__2(7`=`A(B<.`.`!U*TB+
M1=A)*T4`#X64````3(GF2(T]AR<``#'`2(/$$%M!7$%=05Y=Z1WT__],B>9(
MB<?H\^G__TB%P'072(M%V$DK10!U74B#Q!!;05Q!74%>7<-,B>?HO^O__TF)
MQDB)W^BTZ___28U\!@+H*NG__TF)QDF)V$B-#5XF``!,B>)(C35<)P``2(G'
M,<#H6>O__TB+1=A)*T4`=0A,B?;I;____^B"Z___54B)Y4%7059!54%44TB!
M[(@!``!(B;UH_O__2(L%\'P@`$B+"$B)3<@QR4B-!>(F``!(B86`_O__2(T%
MF"4``$B)A8C^__](QX60_O__`````$B-!5,F``!(B87(_O__2(T%LR8``$B)
MA=#^__](C054)@``2(F%V/[__TB-!9\F``!(B87@_O__2,>%Z/[__P````!(
MC06*)@``2(F%J/[__TC'A;#^__\`````3(VM?/[__TR)[DB-/5XE```QP.C,
M[O__2(7`=`F`.``/A4L$```QP.@D_O__28G&2(7`#X3$`P``3(GWZ(/J__](
MC7P``>CYY___2(G#00^V%H32="I)B=],C24A)@``#[;23(GF3(G_,<#H).K_
M_TF#Q@%)@\<"00^V%H32=>!,C;7`_O__2(T]=R4``.L028/&"$F+/DB%_P^$
M%`$``$R)[C'`Z#KN__])B<1(A<!TWH`X`'392(G'Z"SP__^%P'3-3(GGZ-GG
M__](B<)(A<`/A-T```!(B==(B95@_O__Z-[I__])B<1(B=_HT^G__T6-I`0$
M!```36/D3(GGZ$#G__])B<9)B=E,C05U)0``2(T-4B4``$B+E6#^__](C35E
M)0``2(G',<#H9.G__[[``0``3(GWZ*?H__^#^/\/A&\"``!(C;7P_O__3(GW
MZ._H__^)PX7`#X2R````3(GQ2(N%:/[__TB+$$B--=$E``!(BP7B>B``2(VX
M,`$``#'`Z/SG__]%,>1(BP72>B``2(M-R$@K"`^%,`0``$R)X$B!Q(@!``!;
M05Q!74%>05]=PTR+M8#^__]%,>3K$$ECQ$R+M,6`_O__387V=#I!@#X`=#1,
MB??H#>___T&#Q`&%P'3:3(GWZ+;F__](B<)(A<`/A=W^__])8\1,B[3%@/[_
M_TV%]G7&,=+IQO[__XN%^/[__R4`\```/0!````/A3C___^+A0S___]!B<?H
MK^C__T$YQP^%(?___XN%^/[__R7_`0``/<`!```/A0O___],B>?HZ.7__TF)
MQ$R)[DB-/>PC```QP.AT[/__2(G&2(7`#X0X`@``2(N%:/[__TB+..@,\___
M28G%2(7`#X0=`@``3(GOZ"7H__^#^`-^.DACT$F-=!7\N04```!(C3W<(P``
M\Z8/E\*`V@"$TG4:@_@$#X2Y`@``@^@%2)A!@'P%`"\/A*@"```QP.@P^?__
MA<!U%3'V3(GOZ,'E__]!B<6%P`^%Q0$``$B--?0C``!(C3VX(@``,<#HX.__
M_^C,Y/__08G`3(T-MB,``$B-#4$C``!,B?)(C36%(P``3(GG,<#H5^?__TR-
M+90C``#K-^CYX___@S@1=3^#PP'HC.3__T&)P$R)+"1!B=E(C0T!(P``3(GR
M2(TU4R,``$R)YS'`Z!?G__^^P`$``$R)Y^A:YO__@_C_=+=,B??HC>;__TR)
MYDB-/<XA```QP.A+[___3(GGZ+OZ___IUOW__^B*X___@S@1#X2#_?__D.A[
MX___1(L`3(GQ2(N%:/[__TB+$$B--20C``!(BP5U>"``2(VX,`$``#'`Z(_E
M__]%,>3ICOW__S';2(T]5"(``.L02&/#2(N\Q:#^__](A?]T.TR)[C'`Z,+J
M__^#PP%(A<!TWH`X`'392(G'Z&WD__])B<9(A<`/A?;[__](8\-(B[S%H/[_
M_TB%_W7%OPT```#HY^/__TB)PTR--?@A``"Z4P```.GE^___2(G'2(F%:/[_
M_^CK^?__2(L%W7<@`$B+3<A(*PA(BX5H_O__#X4T`0``2(G'2('$B`$``%M!
M7$%=05Y!7UWI\./__TB+A6C^__],BRCIU/W__XG'Z%WX__])B<=(A<`/B"C^
M__](C7#V,=)$B>_H\.+__TB-=8JZ!@```$2)[^B_Y/__2(/X!G0.2(T]G"$`
M`#'`Z&+W__^!?8H`0T%##X7H_?__9H%]CDA%#X7<_?__28UWSC'21(GOZ*3B
M__](C5V0NB@```!(B=Y$B>_H<.3__TB#^"AT#DB-/4TA```QP.@3]___QD6X
M`$R-#74A``!)B=A(C0W](```3(GR2(TU,B$``$R)YS'`Z!/E___I"?[__TB+
MA6C^__],BW@(387_#X1$_?__3(G_Z"+E__](@_@##X8R_?__28UT!_RY!0``
M`$B-/=P@``#SI@^7P!P`A,!-#T3OZ0_]___H`.7__U5(B>5!5D%505132(/L
M$$R+)7IV(`!)BP0D2(E%V#'`9$B+!"4`````2`,%4'8@`$B+``^VD+````"(
MD+$```!,C6W43(GN2(T]AA\``#'`Z+OH__](A<!T"8`X,0^$@`$``#'`Z,KQ
M__]D2(L$)0````!(`P4&=B``28G&N0,```"Z`0```$B--74@``!(BSCHFN+_
M_TB)PTB%P'0G2(M`$$B-%5P@``!(BS!)BS[HG.+__TB+0Q!(BS#V1@Y`#X5$
M`0``9$B+!"4`````2`,%JW4@`$F)QKD#````N@$```!(C34A(```2(LXZ#_B
M__](B<-(A<!T+$R)[DB-/:$>```QP.@&Z/__2(G"2(M#$$B%T@^$V````$B+
M,$F+/N@KXO__9$B+!"4`````2`,%2W4@`$B)P[H!````2(TUR!\``$B+..AD
MX/__2(G&2(T5RQ\``$B+.^CRX?__2(L#QH"Q`````$R)[DB-/2D>```QP.B7
MY___2(G'2(D%U7<@`$B%P'0ROL`!``#H?N+__X/X$70(C5`!@_H!=W=(BT78
M22L$)`^%B@```$B#Q!!;05Q!74%>7<-(BSV?=R``Z+CW__](B<=(B06(=R``
M2(7`=;-(C3WL'P``,<#H#>#__X!X`0`/A'W^___I<?[__TB+%6=W(`!(BS)(
MBSCH0NK__^D<____28L^Z"_@___IK_[__XG!2(L5.7<@`$B+!3IW(`!(BS!(
MC3W`'P``,<#HN=___^C$XO__54B)Y4%42(/L"$F)_#'`Z/'S__^%P'0,387D
M=`=!@#PD`'4(2(/$"$%<7<-,B>?H9.___TB)Q^@M[___N00```!(C3TN'@``
M2(G&\Z8/E\`<`(3`=<Y,B>=(@\0(05Q=Z1WG__]F+@\?A```````#Q]$``!5
M2(GE05=!5D%505132('LF`(``$B+!<5S(`!(BQA(B5W(,=M,C4<X2(V50/W_
M_TR-C<#]__](B=9!BP`/R$V+$$F#P`B)P$B)!DR)T4C!Z2!,B=!(P>@H)0#_
M``!)P>HX3`G028G*2<'B&$6)TDP)T$C!X0B!X0``_P!("<A(B48(2(/&$$PY
MSG6N2(VR``(``$B+0FA(,T)`2#-"$$@S`DB-#`!(P>@?2`G(@^#_2(F"@```
M`$B#P@A(.?)UTTR+#TR+7Q!(BU\83(G(2,'@!4R)RDC!ZAM("=`#A4#]__](
MBW<@C90PF7F"6DR)V$@QV$@C1PA(,=B--`)(BU<(2,'B'DB+1PA(P>@"2`G0
M08G`3(G:3#'"3"'*3#':2(N-2/W__TB-C`N9>8):2`'*2(GQ2,'A!4F)\DG!
MZAM,"=%$C2P*3(G)2,'A'DR)RDC!Z@)("<J)T4@QT$@A\$PQP$R+E5#]__]/
MC903F7F"6DP!T$V)ZDG!X@5-B>Q)P>P;30GB1HTD$$B)\$C!X!Y(P>X"2`GP
MB<9(,<),(>I(,<I,BY58_?__3XV$$)EY@EI)`=!,B>)(P>(%38GB2<'J&TP)
MTD6-%!!-B>A)P>`>2<'M`DT)Z$2)PDPQP$PAX$@Q\$R+K6#]__]*C8PIF7F"
M6D@!P4R)T$C!X`5-B=5)P>T;3`GH1(TL`4R)X4C!X1Y)P>P"3`GAB<A),<A-
M(=!),=!,BZ5H_?__2HVT)IEY@EI)`?!,B>Y(P>8%38GL2<'L&TP)YD6-)#!,
MB=9(P>8>2<'J`DP)UD&)\$@Q\4PAZ4@QP4R+E7#]__]*C902F7F"6D@!T4R)
MXDC!X@5-B>))P>H;3`G21(T4$4R)ZDC!XAY)P>T"3`GJB=%(,=9,(>9,,<9,
MBZUX_?__2HV$*)EY@EI(`<9,B=!(P>`%38G52<'M&TP)Z$2-+`9,B>!(P>`>
M2<'L`DP)X(G&2#'"3"'22#'*3(NE@/W__T^-A""9>8):20'03(GJ2,'B!4V)
M[$G![!M,">)%C20038G02<'@'DG!Z@)-"=!$B<),,<!,(>A(,?!,BY6(_?__
M2HV,$9EY@EI(`<%,B>!(P>`%38GB2<'J&TP)T$2-%`%,B>E(P>$>2<'M`DP)
MZ8G(23'(32'@23'03(NMD/W__TJ-M"Z9>8):20'P3(G62,'F!4V)U4G![1M,
M">Y%C2PP3(GF2,'F'DG![`),">9!B?!(,?%,(=%(,<%,BZ68_?__2HV4(IEY
M@EI(`=%,B>I(P>(%38GL2<'L&TP)XD2-)!%,B=)(P>(>2<'J`DP)THG12#'6
M3"'N3#'&3(N5H/W__TJ-A!"9>8):2`'&3(G@2,'@!4V)XDG!ZAM,"=!$C10&
M3(GH2,'@'DG![0),">B)QD@QPDPAXD@QRDR+K:C]__]/C80HF7F"6DD!T$R)
MTDC!X@5-B=5)P>T;3`GJ18TL$$V)X$G!X!Y)P>P"30G@1(G"3#'`3"'02#'P
M3(NEL/W__TJ-C"&9>8):2`'!3(GH2,'@!4V)[$G![!M,">!$C20!3(G12,'A
M'DG!Z@),"=&)R$DQR$TAZ$DQT$R+E;C]__]*C;06F7F"6DD!\$R)YDC!Y@5-
MB>))P>H;3`G618T4,$R)[DC!YAY)P>T"3`GN08GP2#'Q3"'A2#'!3(NMP/W_
M_TJ-E"J9>8):2`'13(G22,'B!4V)U4G![1M,">I$C3013(GB2,'B'DG![`),
M">*)T4@QUDPAUDPQQDR+I<C]__]*C80@F7F"6D@!QDR)\$C!X`5-B?1)P>P;
M3`G@1(TL!DR)T$C!X!Y)P>H"3`G008G$2#'"3"'R2#'*2(NUT/W__TV-A#"9
M>8):20'03(GJ2,'B!4R)[DC![AM("?*)TDD!T$6)PDR)]DC!YAY)P>X"3`GV
M2#'P3"'H3#'@2(N5V/W__TB-C!&9>8):2`'!3(G02,'@!4R)TDC!ZAM("=")
MP$@!P4&)SDR)ZDC!XAY)P>T"3`GJ2(GP2#'003'`2(N%X/W__TF-A`2AZ]EN
M20'`3(GP2,'@!4V)]$G![!M,">")P$D!P$6)Q$R)T$C!X!Y)P>H"3`G0B?9(
M`[7H_?__28G223'"1#'13(V4#J'KV6Y,B>%(P>$%3(GF2,'N&T@)\8G)20'*
M18G53(GQ2,'A'DG![@),"?&)TD@#E?#]__](B<9(,<Y$,<9,C80RH>O9;DR)
MZDC!X@5,B>Y(P>X;2`GRB=))`=!%B<9,B>9(P>8>2<'L`DP)YHG`2`.%^/W_
M_TB)RD@Q\D0QTDR-E!"AZ]EN3(GP2,'@!4R)\DC!ZAM("=")P$D!PD6)U$R)
MZDC!XAY)P>T"3`GJB<E(`XT`_O__2(GP2#'01#'`3(V$`:'KV6Y,B>!(P>`%
M3(GA2,'I&T@)R(G`20'`18G%3(GP2,'@'DG![@),"?")]D@#M0C^__](B=%(
M,<%$,=%,C90.H>O9;DR)Z4C!X05,B>Y(P>X;2`GQB<E)`<I%B=9,B>%(P>$>
M2<'L`DP)X8G22`.5$/[__TB)QD@QSD0QQDR-A#*AZ]EN3(GR2,'B!4R)]DC!
M[AM("?*)TDD!T$6)Q$R)[DC!YAY)P>T"3`GNB<!(`X48_O__2(G*2#'R1#'2
M3(V4$*'KV6Y,B>!(P>`%3(GB2,'J&T@)T(G`20'"18G53(GR2,'B'DG![@),
M"?*)R4@#C2#^__](B?!(,=!$,<!,C80!H>O9;DR)Z$C!X`5,B>E(P>D;2`G(
MB<!)`<!%B<9,B>!(P>`>2<'L`DP)X(GV2`.U*/[__TB)T4@QP40QT4R-E`ZA
MZ]EN3(GQ2,'A!4R)]DC![AM("?&)R4D!RD6)U$R)Z4C!X1Y)P>T"3`GIB=)(
M`Y4P_O__2(G&2#'.1#'&3(V$,J'KV6Y,B>)(P>(%3(GF2,'N&T@)\HG220'0
M18G%3(GV2,'F'DG![@),"?:)P$@#A3C^__](B<I(,?)$,=),C900H>O9;DR)
MZ$C!X`5,B>I(P>H;2`G0B<!)`<)%B=9,B>)(P>(>2<'L`DP)XHG)2`.-0/[_
M_TB)\$@QT$0QP$R-A`&AZ]EN3(GP2,'@!4R)\4C!Z1M("<B)P$D!P$6)Q$R)
MZ$C!X!Y)P>T"3`GHB?9(`[5(_O__2(G12#'!1#'13(V4#J'KV6Y,B>%(P>$%
M3(GF2,'N&T@)\8G)20'*18G53(GQ2,'A'DG![@),"?&)TD@#E5#^__](B<9(
M,<Y$,<9,C80RH>O9;DR)ZDC!X@5,B>Y(P>X;2`GRB=))`=!%B<9,B>9(P>8>
M2<'L`DP)YHG`2`.%6/[__TB)RD@Q\D0QTDR-I!"AZ]EN3(GP2,'@!4R)\DC!
MZAM("=")P$D!Q$6)XDR)ZDC!XAY)P>T"3`GJB<E(`XU@_O__2(GP2#'01#'`
M3(V$`:'KV6Y,B=!(P>`%3(G12,'I&T@)R(G`20'`18G%3(GP2,'@'DG![@),
M"?")]D@#M6C^__](B=%(,<%$,>%,C:0.H>O9;DR)Z4C!X05,B>Y(P>X;2`GQ
MB<E)`<Q%B>=,B=%(P>$>2<'J`DP)T8G22`.5</[__TB)QD@QSD0QQDB-M#*A
MZ]EN3(GZ2,'B!4V)^$G!Z!M,"<)$C10638GH2<'@'DG![0)-">A$B<:)P$@#
MA7C^__](B<I,,<)$,>)(C900H>O9;DR)T$C!X`5-B=1)P>P;3`G@1(TL`DV)
M_$G!Y!Y)P>\"30G\1(GB38G&30GF32'622'030G&N-R\&X],BX6`_O__20'`
MB<E,`<%)`<Y,B>E(P>$%38GH2<'H&TP)P46-!`Y,B=%(P>$>2<'J`DP)T4&)
MRDD)S$TA[$F)SDDAUDT)]$R+M8C^__])`<9,`?9,`>9-B<1)P>0%38G&2<'N
M&TT)]$:--"9,B>Y(P>8>2<'M`DP)[D&)]4F)S$D)]$TAQ$PAZ4P)X4R+I9#^
M__])`<1,`>)(`=%,B?)(P>(%38GT2<'L&TP)XD2-)!%,B<)(P>(>2<'H`DP)
MPD&)T$@)UDPA]DB)T4PAZ4@)SDB+C9C^__](`<%,`=%(`?%,B>9(P>8%38GB
M2<'J&TP)UD2-/#%-B?))P>(>2<'N`DT)\D2)UDB)T4P)T4PAX4@A\D@)RDB+
MC:#^__](`<%,`>E(`<I,B?E(P>$%38G]2<'M&TP)Z42-+`I,B>%(P>$>2<'L
M`DP)X4&)S$D)RDTA^DB)RD@A\DD)TDB+E:C^__](`<),`<),`=)-B>A)P>`%
M38GJ2<'J&TT)T$:--`)-B?A)P>`>2<'O`DT)^$6)PDB)RDP)PDPAZDPAT4@)
MT4B+E;#^__](`<)(`?)(`=%,B?)(P>(%3(GV2,'N&T@)\HTT$4R)ZDC!XAY)
MP>T"3`GJ08G520G032'P2(G13"'120G(2(N-N/[__T@!P4P!X4P!P4F)\$G!
MX`5)B?1)P>P;30G@1HT\`4V)]$G!Y!Y)P>X"30GT18G@2(G13`GA2"'Q3"'"
M2`G*2(N-P/[__T@!P4P!T4@!RDR)^4C!X05-B?I)P>H;3`G11(T4"DB)\4C!
MX1Y(P>X"2`GQB<Y)"<Q-(?Q(B<I,(<))"=1(BY7(_O__2`'"3`'J3`'B38G4
M2<'D!4V)U4G![1M-">Q&C30B38G]2<'E'DG![P)-"?U%B>Q(B<I,">I,(=),
M(>%("=%(BY70_O__2`'"3`'"2`'13(GR2,'B!4V)\$G!Z!M,"<)$C0013(G2
M2,'B'DG!Z@),"=)!B=))"=5-(?5(B=%,(>%)"<U(BXW8_O__2`'!2`'Q3`'I
M3(G&2,'F!4V)Q4G![1M,">Y$C3PQ3(GV2,'F'DG![@),"?9!B?9(B=%("?%,
M(<%,(?)("<I(BXW@_O__2`'!3`'A2`'*3(GY2,'A!4V)_$G![!M,">%$C20*
M3(G!2,'A'DG!Z`),"<%!B<A("<Y,(?Y(B<I,(?)("=9(BY7H_O__2`'"3`'2
M2`'R3(GF2,'F!4V)XDG!ZAM,"=9$C2PR38GZ2<'B'DG![P)-"?I$B=9(B<I,
M"=),(>)((?%("=%(BY7P_O__2`'"3`'R2`'13(GJ2,'B!4V)[DG![AM,"?)$
MC3013(GB2,'B'DG![`),">*)T4D)TDTAZDF)U$DA]$T)XDR+I?C^__])`<1-
M`>!-`=!-B?))P>(%38GT2<'L&TT)XD>-)!!-B>A)P>`>2<'M`DT)Z$6)PDF)
MU4T)Q4TA]4PATDP)ZDR+K0#___])`<5,`>Y(`?),B>9(P>8%38GE2<'M&TP)
M[D2-+#),B?9(P>8>2<'N`DP)]D&)]TD)\$TAX$B)\DPATDD)T$B+E0C___](
M`<)(`<I,`<),B>E(P>$%38GH2<'H&TP)P42-!`I,B>%(P>$>2<'L`DP)X4&)
MS$B)\D@)RDPAZDPAYD@)UDB+E1#___](`<),`=)(`=9,B<)(P>(%38G"2<'J
M&TP)THG22`'608GR3(GJ2,'B'DG![0),">I!B=9("=%,(<%)B=5-(>5,">E(
M`X48____3`'X2`'!3(G02,'@!4V)U4G![1M,">B)P$@!P4&)S4R)P$C!X!Y)
MP>@"20G`3#'",=:XUL%BRDB+E2#___](`<),`>)(`?),B>Y(P>8%38GL2<'L
M&TP)YHGV2`'R08G43(G62,'F'DG!Z@))"?),B<9,,=8Q\4B+M2C___](`<9)
M`?9)`<Y,B>%(P>$%3(GF2,'N&T@)\8G)20'.18GW3(GI2,'A'DG![0))"<U(
MBXTP____2`'!18G`3`'!3(G63#'N,?)(`<I,B?E(P>$%3(G^2,'N&T@)\8G)
M2`'*08G03(GA2,'A'DG![`),">%(B[4X____2`'&18G23`'638GJ23'*13'R
M20'R3(G&2,'F!4V)Q$G![!M,">:)]DD!\D6)U$R)_DC!YAY)P>\"20GW2(NU
M0/___T@!QD6)[4P![DF)S4TQ_4$QU4P![DR)XDC!X@5-B>5)P>T;20G518GM
M20'U18GN3(G&2,'F'DG!Z`),"<9(BY5(____2`'"B<E(`<I-B?A),?!%,=!)
M`=!,B?)(P>(%3(GQ2,'I&T@)RHG220'018G"3(GB2,'B'DG![`))"=1(BY50
M____2`'"18G_3`'Z2(GQ3#'A03'-20'53(G22,'B!4R)T4C!Z1M("<J)TDD!
MU46)[TR)\DC!XAY)P>X"3`GR2(N-6/___T@!P8GV2`'Q3(GF2#'603'P20'(
M3(GY2,'A!4R)_DC![AM("?&)R4D!R$6)QDR)T4C!X1Y)P>H"20G*2(N-8/__
M_T@!P46)Y$P!X4F)U$TQU$4Q[$D!S$R)\4C!X05,B?9(P>X;2`GQB<E)`<Q%
MB>5,B?E(P>$>2<'O`DP)^4B+M6C___](`<:)TD@!\DR)UD@QSD$Q\$D!T$R)
MZDC!X@5,B>Y(P>X;2`GRB=))`=!%B<=,B?)(P>(>2<'N`DD)UDB+E7#___](
M`<)%B=),`=))B<I-,?)%,>))`=),B?I(P>(%3(G^2,'N&T@)\HG220'218G4
M3(GN2,'F'DG![0),">Y(BY5X____2`'"B<E(`<I,B?%(,?%!,<A)`=!,B>)(
MP>(%3(GA2,'I&T@)RHG220'018G%3(GZ2,'B'DG![P))"==(BU6`2`'"18GV
M3`'R2(GQ3#'Y03'*20'23(GJ2,'B!4R)Z4C!Z1M("<J)TDD!TD6)UDR)XDC!
MXAY)P>P"3`GB2(M-B$@!P8GV2`'Q3(G^2#'61#'&2`'.3(GQ2,'A!4V)\$G!
MZ!M,"<&)R4@!SD&)\$R)Z4C!X1Y)P>T"20G-2(M-D$@!P46)_TP!^4F)U$TQ
M[$4QU$D!S$R)P4C!X05-B<))P>H;3`G1B<E)`<Q%B>),B?%(P>$>2<'N`DP)
M\4R+=9A)`<:)TDP!\DV)[DDQSD0Q]D@!UDR)TDC!X@5-B=9)P>X;3`GRB=)(
M`=9!B?9,B<)(P>(>2<'H`DD)T$B+5:!(`<)%B>U,`>I)B<U-,<5%,>Q)`=1,
MB?)(P>(%38GU2<'M&TP)ZHG220'41(GB38G52<'E'DG!Z@)-">I,BVVH20'%
MB<E,`>E-B<5-,=5$,>Y(`?%(B=9(P>8%28G52<'M&TP)[HGV2`'QB<Y-B?5)
MP>4>2<'N`DT)[DR+;;!)`<5%B<!-`>A-B=5-,?5%,>Q-`>!)B?1)P>0%28GU
M2<'M&TT)[$4!X$F)U$G!Y!Y(P>H"3`GB2`-%N$D!P46)TDT!T4R)\$@QT#'!
M3`')3(G`2,'@!4V)P4G!Z1M,"<@!R$B)!T0#1PA,B4<(2(GP2,'@'DC![@)(
M"<9!`?-,B5\0`=I(B5<81`-W($R)=R!(BP5/7B``2(M=R$@K&'422('$F`(`
M`%M!7$%=05Y!7UW#Z)_,__]52(GEOX````#H`<K__TC'``$C16>ZB:O-[TB)
M4`BY_MRZF$B)2!!(QT`8=E0R$+[PX=+#2(EP($C'0"@`````2,=`,`````#'
M0'@`````7<-52(GE05=!5D%505132(/L&$F)_TB)\TACPDF)QDB+?RB--,=)
MBU<P2#G^2(/2`$F)=RA(P>@=2`'028E',$EC?WA-C6<XA?]T4T&]0````$$I
M_44Y[D4/3NY)8]5,`>=(B57(2(G>Z+++__]!BT=X1`'H08E'>(/X0$B+5<AT
M#TB#Q!A;05Q!74%>05]=PT4I[D@!TTR)_^AAZ?__08/^/P^.^P```$&#[D!$
MB?#!Z`:)1<A$C6@!2<'E!DD!W4B+`TF)!"1(BT,(28E$)`A(BT,028E$)!!(
MBT,828E$)!A(BT,@28E$)"!(BT,H28E$)"A(BT,P28E$)#!(BT,X28E$)#A(
M@\-`3(G_Z.WH__],.>MUJ8M%R,'@!D$IQDECQDR)YTR)[DB#^`AS-:@$=2JH
M`G4>J`%U$T6)=WA(@\086T%<05U!7D%?7<.D18EW>.OJ9J6H`73@Z_&EJ`)T
MU>OQ0?;$`75!0/;'`I!U44#VQP1U7TB#^`ARLDF)P4F#X?@QTDR+!!9,B007
M2(/""$PYRG+O2`'72`'6J`1TDNNZ28G=Z77___]!#[95`$&(5SA(@\<!2(/&
M`4B#Z`'KJ`^W%F:)%TB#QP)(@\8"2(/H`NN;BQ:)%TB#QP1(@\8$2(/H!.N/
M54B)Y4%7059!54%44TB#[`A(B?M)B?1$BW8H00_.1(M^,$$/STB+1BA(P>@#
M@^`_3(UN.(U(`4B80<9$!0"`2&/Y3`'O@_DX#XZ6`0``ND`````IRG0/,<")
MP<8$#P"#P`$YT'+S3(GGZ*GG__],B>^Y.````#'`0?;%`0^%YP$``$#VQP(/
MA>@!``!`]L<$#X7*`0``08G(08/@X#'2B=9(B00W2(E$-PA(B40W$$B)1#<8
M@\(@1#G"<N-(`=?VP1!T!$BK2*OVP0AT`DBK]L$$=`&K]L$"=`)FJX/A`0^%
M,P$``$6)?"1P18ET)'1,B>?H(.?__TF+!"1(P>@8B`-)BP0D2,'H$(A#`4F+
M!"1(P>@(B$,"28L$)(A#`TF+1"0(2,'H&(A#!$F+1"0(2,'H$(A#!4F+1"0(
M2,'H"(A#!DF+1"0(B$,'28M$)!!(P>@8B$,(28M$)!!(P>@0B$,)28M$)!!(
MP>@(B$,*28M$)!"(0PM)BT0D&$C!Z!B(0PQ)BT0D&$C!Z!"(0PU)BT0D&$C!
MZ`B(0PY)BT0D&(A##TF+1"0@2,'H&(A#$$F+1"0@2,'H$(A#$4F+1"0@2,'H
M"(A#$DF+1"0@B$,33(GG2(/$"%M!7$%=05Y!7UWIT\?__[HX````*<HQP(/Z
M(',L]L(0=`1(JTBK]L((=`)(J_;"!'0!J_;"`G0"9JN#X@$/A,W^__^JZ<?^
M__]`]L<!=6=`]L<"=5I`]L<$=4Z#^B!RO4&)T$&#X.`Q]HGQ2(D$#TB)1`\(
M2(E$#Q!(B40/&(/&($0YQG+C2`'WZY*K@^D$Z2W^__^JN3<```#I#O[__V:K
M@^D"Z0[^__^K@^H$ZZQFJX/J`NN?JH/J`>N39@\?1```Z%O$___H5L3__U5(
MB>5!54%44TB#[#B)?<Q(B77`2(E5N$B+'3=9(`!(BP-(B478,<!(C56X2(UU
MP$B-?<SH#<;__TB+-3Y9(`!(B?)(BSTL62``Z*?$__](BP706"``@#@`=3?H
MAL7__TB)QTB)!<1;(`!(A<`/A'H!``#H/L;__V1(BP0E`````$@#!;Y8(`!(
MBP#&@%X(````9$B+!"4`````2`,%I%@@`$B+`("(V@,```.+1<Q$C6`#C7@$
M2&/_2,'G`^C4Q?__28G!2(D%6EL@`$B+3<!(BP%)B0%(C040`P``28E!"$B-
M!?Y:(`!(BP!)B4$02(T%^@(``$F)01B+?<R#_P$/CMT```!(@\$(@\<#N`0`
M``!(8]"#P`%(BS%)B3312(/!"#GX=>M(F$G'!,$`````13'`3(G)1(GB2(TU
M^-#__TB+/>9:(`#H*<3__X7`=%%(BSW66B``Z,G$__]!B<1,C6W43(GN2(T]
M/`$``#'`Z&'*__](A<!T-DB+/:U:(`#H(,;__^B[PO__2(M%V$@K`W5C1(G@
M2(/$.%M!7$%=7<-(BSV%6B``Z-C$___KH4B+/6=:(`!(A?]T!^A!X___Z[=,
MB>Y(C3V4````Z`3*__](B<=(B05"6B``2(7`=)GKV;@$````Z3K___^_`0``
M`.AOQ/__Z,K%__\`````````````2(/L".@+R?__2(/$",,``"5S+R5S`"X`
M+W!R;V,O8W5R<')O8R]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`%!!4E]414U0`%!!4E]04D]'3D%-10`Z
M`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(
M10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$
M25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`;'-E96L@9F%I
M;&5D`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-94U1%30`O
M=&UP+P!414U01$E2`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`
M<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#8Q`"UE`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%
M7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%2
M7TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[
M("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?
M34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*
M;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I
M("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S
M(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@
M,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@
M)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O
M9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T
M<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD
M(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I
M('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,[
M"GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@
M7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N
M<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&
M24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S
M96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(
M+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T
M:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&
M24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D
M4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X[
M"GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\
M+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET
M=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A
M9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S
M*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I
M;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N
M="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z
M("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D
M>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R
M="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^
M<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H
M95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K
M("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@
M,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4[
M"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<
M,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R
M('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E
M860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I
M>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F
M(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC
M;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@
M)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E
M("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A
M73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%
M``!P97)L>'-I+F,````!&P,[&`$``"(```"D@?__+`(``'2%__]4`@``M(7_
M_S0!``#>A?__6`$``":&__^T`0``=8?__P0"``!4B?__;`(```**__^8`@``
M6XO__\0"``#;B___[`(``(J,__\<`P``8XW__T@#``"%C___>`,``+>/__^8
M`P``!)#__[@#```'D/__S`,``.F1___X`P``&)+__Q@$``!XDO__4`0``(66
M__]\!```VY;__Z`$``"7E___O`0``,&8___H!```VYC__P@%``#"F?__/`4`
M`$2@__]T!0``@*+__Z`%``#THO__]`4``*6X__\D!@``]KC__T0&``#=NO__
M>`8``'2]__^@`0``>;W___`!``!^O?__R`4``!0``````````7I2``%X$`$;
M#`<(D`$``"`````<````>(3__RH`````00X0A@)##09#C`.#!&(,!P@``"``
M``!`````?H3__T@`````00X0A@)##09)C0.,!(,%>@P'""```````````7I2
M``%X$`$;#`<(D`$,!A"#!88"C`2-`P```!`````H````S+O__P4`````````
M'````)P```!JA/__3P$````#.@$.$(8"0PT&10P'",88``````````%Z4@`!
M>!`!&PP'")`!#`80A@(`$````"````"!N___!0`````````D````[````&F%
M__\C`0```$$.$(8"0PT&1XX#C02,!8,&````````)````!0!``!P?___T`,`
M```.$$8.&$H/"W<(@``_&CLJ,R0B`````!0````\`0``&(/__R``````````
M`````"@```!4`0``X(;__ZX`````00X0A@)##09-CP..!(T%C`:#!P)_"@P'
M"$$+*````(`!``!BA___60$```!!#A"&`D,-!E"/`XX$C06,!H,'>PH,!PA!
M"P`D````K`$``(^(__^``````$$.$(8"0PT&2HP#@P0";`H,!PA!"P``+```
M`-0!``#GB/__KP````!!#A"&`D,-!DJ,`X,$`G8*#`<(00M@"@P'"$4+````
M*`````0"``!FB?__V0````!!#A"&`D,-!E"/`XX$C06,!H,'`KH*#`<(00LL
M````,`(``!.*__\B`@```$$.$(8"0PT&38\#C@2-!8P&@P<#$@$*#`<(00L`
M```<````8`(```6,__\R`````$$.$(8"0PT&:0P'"````!P```"``@``%XS_
M_TT`````00X0A@)##09%@P-_#`<($````*`"``!$C/__`P`````````H````
MM`(``#.,___B`0```$$.$(8"0PT&4(\#C@2-!8P&@P<"<@H,!PA!"QP```#@
M`@``Z8W__R\`````00X0A@)##09&C`-@#`<(-``````#``#XC?__8`````!&
M#A"&`D,-!D:,`V(*S$'&#`<(10M-"LQ!Q@P'"$4+20P'"$'&S``H````.`,`
M`"".__\-!````$$.$(8"0PT&28T#C`2#!0/-`PH,!PA%"P```"````!D`P``
M`9+__U8`````00X0A@)##09%@P,"0PH,!PA!"Q@```"(`P``,Y+__[P`````
M00X0A@)##08````H````I`,``-.2__\J`0```$$.$(8"0PT&4(\#C@2-!8P&
M@P<"U@H,!PA!"QP```#0`P``T9/__QH`````00X0A@)##095#`<(````,```
M`/`#``#+D___YP````!!#A"&`D,-!DN.`XT$C`6#!@)7"@P'"$4+9@H,!PA!
M"P```#0````D!```?I3__X(&````00X0A@)##090CP..!(T%C`:#!P--`@H,
M!PA!"P/[`@H,!PA%"P``*````%P$``#(FO__/`(```!!#A"&`D,-!DN.`XT$
MC`6#!@.J`0H,!PA!"P`D````B`0``-B<__]E`````$$.$(8"0PT&1HP#80H,
M!PA!"W0,!P@`*````+`$``"NM____`$```!!#A"&`D,-!DF-`XP$@P4#E`$*
M#`<(00L````L````W`0``/B<__^Q%0```$$.$(8"0PT&4(\#C@2-!8P&@P<#
MEQ4*#`<(00L````<````#`4``'FR__]1`````$$.$(8"0PT&`DP,!P@``#``
M```L!0``JK+__^<!````00X0A@)##09-CP..!(T%C`:#!P)]"@P'"$$+`KT*
M#`<(00LL````8`4``%VT__^1`@```$$.$(8"0PT&38\#C@2-!8P&@P<#S@$*
M#`<(10L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````,("`````````0``````
M``#,`@````````$`````````X0(````````!```````````#````````#P``
M``````!M!`````````P`````````D!H````````-`````````(!8````````
M!`````````!(`@````````4`````````R`X````````&`````````&@%````
M````"@````````"T!`````````L`````````&``````````5````````````
M`````````P``````````L"````````(`````````H`4````````4````````
M``<`````````%P````````#H%`````````<`````````@!,````````(````
M`````&@!````````"0`````````8`````````/O__V\`````````"`````#Y
M__]O``````0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````X*T@````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#@K2````````````````````````````"V&@```````,8:
M````````UAH```````#F&@```````/8:````````!AL````````6&P``````
M`"8;````````-AL```````!&&P```````%8;````````9AL```````!V&P``
M`````(8;````````EAL```````"F&P```````+8;````````QAL```````#6
M&P```````.8;````````]AL````````&'````````!8<````````)AP`````
M```V'````````$8<````````5AP```````!F'````````'8<````````AAP`
M``````"6'````````*8<````````MAP```````#&'````````-8<````````
MYAP```````#V'`````````8=````````%AT````````F'0```````#8=````
M````1AT```````!6'0```````&8=````````=AT```````"&'0```````)8=
M````````IAT```````"V'0```````,8=````````UAT```````#F'0``````
M`/8=````````!AX````````6'@```````"8>````````-AX```````!&'@``
M`````%8>````````9AX```````"(LB````````"R(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H``````````'A;````````1T-#
M.B`H3F5T0E-$(&YB,R`R,#(S,3`P."D@,3`N-2XP`$=#0SH@*&YB,R`R,#(S
M,3`P."D@,3`N-2XP`"1.971"4T0Z(&-R=#`N4RQV(#$N-"`R,#$X+S$Q+S(V
M(#$W.C,W.C0V(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L
M=B`Q+C(W(#(P,C(O,#8O,C$@,#8Z-3(Z,3<@<VMR;&P@17AP("0`)$YE=$)3
M1#H@8W)T:2Y3+'8@,2XQ(#(P,3`O,#@O,#<@,3@Z,#$Z,S4@:F]E<F<@17AP
M("0`)$YE=$)31#H@8W)T8F5G:6XN4RQV(#$N,B`R,#$P+S$Q+S,P(#$X.C,W
M.C4Y(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XQ(#(P,3`O
M,#@O,#<@,3@Z,#$Z,S0@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T;BY3+'8@
M,2XQ(#(P,3`O,#@O,#<@,3@Z,#$Z,S4@:F]E<F<@17AP("0``/'/`@``````
M```````````(````"`````@````(````&P````$``````````"HJ*B!.;R!,
M86)E;"!0<F]V:61E9"`J*BH``/'/`@`````````````````(````"`````@`
M```(````&P````$``````````"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J*BH`
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N;F]T92YN
M971B<V0N<&%X`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA
M;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?8W1F````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@```````````@`````````"
M````````%P````````````````````$````````````````````3````!P``
M``(`````````&`(````````8`@```````!@````````````````````$````
M````````````````)@````<````"`````````#`"````````,`(````````4
M````````````````````!````````````````````#<````%`````@``````
M``!(`@```````$@"````````'`,````````%``````````@`````````!```
M```````]````"P````(`````````:`4```````!H!0```````&`)````````
M!@````$````(`````````!@`````````10````,````"`````````,@.````
M````R`X```````"T!````````````````````0```````````````````$T`
M```$`````@````````"`$P```````(`3````````:`$````````%````````
M``@`````````&`````````!7````!````$(`````````Z!0```````#H%```
M`````*`%````````!0```!8````(`````````!@`````````80````$````&
M`````````)`:````````D!H````````.````````````````````$```````
M`````````````%P````!````!@````````"@&@```````*`:````````T`,`
M`````````````````!``````````$`````````!G`````0````8`````````
M<!X```````!P'@```````"`````````````````````(``````````@`````
M````<`````$````&`````````)`>````````D!X```````#F.0``````````
M````````$````````````````````'8````!````!@````````"`6```````
M`(!8````````#@```````````````````!````````````````````!\````
M`0````(`````````D%@```````"06````````&I````````````````````(
M````````````````````A`````$````"`````````/R8````````_)@`````
M```<`0``````````````````!````````````````````)(````!`````@``
M```````8F@```````!B:````````E`4```````````````````@`````````
M``````````"<`````0````,`````````N*T@``````"XK0```````!``````
M```````````````(````````````````````HP````$````#`````````,BM
M(```````R*T````````0````````````````````"```````````````````
M`*H````!`````P````````#8K2```````-BM````````"```````````````
M``````@```````````````````"O````!@````,`````````X*T@``````#@
MK0```````,`!````````!@`````````(`````````!``````````:P````$`
M```#`````````*"O(```````H*\```````!@````````````````````"```
M```````(`````````+@````!`````P``````````L"````````"P````````
M^`$```````````````````@`````````"`````````#!`````0````,`````
M````^+$@``````#XL0```````'`````````````````````(````````````
M````````QP````@````#`````````("R(```````:+(```````!(````````
M````````````0````````````````````,P````!````,```````````````
M`````&BR````````/0````````````````````$``````````0`````````?
M`````0```#````````````````````"EL@```````%(!````````````````
M```!``````````$`````````U0````$`````````````````````````^+,`
M``````"/````````````````````!`````````````````````$````#````
M`````````````````````(>T````````WP````````````````````$`````
+````````````````
